@@ -92,17 +92,15 @@ void overview_coordinate_update(cache_context_t *context) {
   gtk_widget_show_all(context->bearing_hbox);
 }
 
-#ifdef USE_MAEMO
 #ifdef ENABLE_BROWSER_INTERFACE
 static void on_www_clicked(GtkButton *button, gpointer data) {
   cache_context_t *context = (cache_context_t*)data;
-  dbus_browser_url(context->appdata, context->cache->url);
+  browser_url(context->appdata, context->cache->url);
 }
 #endif
-#endif
 
 static GtkWidget *cache_overview(cache_context_t *context) {
-  GtkWidget *vbox, *ivbox, *ihbox;
+  GtkWidget *vbox, *ivbox;
   GtkWidget *table, *tip;
   char str[64];
 #ifndef USE_MAEMO
@@ -140,9 +138,25 @@ static GtkWidget *cache_overview(cache_context_t *context) {
   if(cache->id) {
     int strike = cache->archived?STRIKETHROUGH_RED:
       (!cache->available?STRIKETHROUGH:STRIKETHROUGH_NONE);
-    gtk_table_attach_defaults(GTK_TABLE(table), 
-	      gtk_label_attrib(cache->id, SIZE_BIG,strike), 1,2,0,1);
+    GtkWidget *lbl = NULL;
+    
+#ifdef ENABLE_BROWSER_INTERFACE
+    if(!cache->url) 
+#endif
+      lbl = gtk_label_attrib(cache->id, SIZE_BIG, strike);
+#ifdef ENABLE_BROWSER_INTERFACE
+    else {
+      /* add Go button */
+      lbl = gtk_button_attrib(cache->id, SIZE_BIG, strike);
+      //      gtk_button_set_relief(GTK_BUTTON(button),GTK_RELIEF_NONE);
+      gtk_signal_connect(GTK_OBJECT(lbl), "clicked",
+			 (GtkSignalFunc)on_www_clicked, context);
+    }
+#endif
+
+    gtk_table_attach(GTK_TABLE(table), lbl, 1,2,0,1, FALSE, FALSE, 0, 0);
   }
+
   /* --------------- box containing owner info ------------- */
   if(cache->owner) {
     ivbox = gtk_vbox_new(FALSE, 0);
@@ -209,37 +223,6 @@ static GtkWidget *cache_overview(cache_context_t *context) {
     gtk_box_pack_start_defaults(GTK_BOX(vbox), 
 	html_view(appdata, cache->short_description, 
 		  cache->short_is_html, TRUE, cache, NULL));
-	
-  /* ------------ caches url on geocaching.com ------------ */
-  if(cache->url) {
-    if(cache->short_description)
-      gtk_box_pack_start(GTK_BOX(vbox), gtk_hseparator_new(),FALSE,FALSE,0);
-
-    ihbox = gtk_hbox_new(FALSE, 0);
-    
-    GtkWidget *label = gtk_label_new(cache->url);
-    gtk_misc_set_alignment(GTK_MISC(label), 0.f, 0.5f);
-    gtk_label_set_ellipsize(GTK_LABEL(label), 
-			    PANGO_ELLIPSIZE_MIDDLE);
-
-    gtk_box_pack_start_defaults(GTK_BOX(ihbox), label);
-
-#ifdef USE_MAEMO
-#ifdef ENABLE_BROWSER_INTERFACE
-    /* add Go button */
-    GtkWidget *button = gtk_button_new();
-    gtk_button_set_relief(GTK_BUTTON(button),GTK_RELIEF_NONE);
-    gtk_button_set_image(GTK_BUTTON(button), icon_get_widget(ICON_MISC, 7));
-    gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		       (GtkSignalFunc)on_www_clicked, context);
-   
-    gtk_box_pack_start(GTK_BOX(ihbox), button, FALSE, FALSE, 0);
-#endif
-#endif
-
-    gtk_box_pack_start(GTK_BOX(vbox), ihbox, FALSE, FALSE, 0);
-  }
-
 
   return vbox;
 }
@@ -300,9 +283,13 @@ static GtkWidget *cache_hint(appdata_t *appdata, cache_t *cache) {
 static GtkWidget *cache_wpts(appdata_t *appdata, wpt_t *wpt) {
   pos_t *refpos = NULL;
 
+#ifndef USE_PANNABLE_AREA
   GtkWidget *scrolled_window = gtk_scrolled_window_new(NULL, NULL);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window), 
   				 GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+#else
+  GtkWidget *pannable_area = hildon_pannable_area_new();
+#endif
 
   GtkWidget *vbox = gtk_vbox_new(FALSE, 0);
 
@@ -391,18 +378,27 @@ static GtkWidget *cache_wpts(appdata_t *appdata, wpt_t *wpt) {
 
   gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, 0);
 
+#ifndef  USE_PANNABLE_AREA
   gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scrolled_window), 
 					vbox);
-
   return scrolled_window;
+#else
+  hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA(pannable_area),
+					 vbox);
+  return pannable_area;
+#endif
 }
 
 static GtkWidget *cache_tbs(appdata_t *appdata, tb_t *tb) {
   pos_t *refpos = NULL;
 
+#ifndef USE_PANNABLE_AREA
   GtkWidget *scrolled_window = gtk_scrolled_window_new(NULL, NULL);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window), 
   				 GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+#else
+  GtkWidget *pannable_area = hildon_pannable_area_new();
+#endif
 
   GtkWidget *vbox = gtk_vbox_new(FALSE, 0);
 
@@ -433,18 +429,26 @@ static GtkWidget *cache_tbs(appdata_t *appdata, tb_t *tb) {
 
   gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, 0);
 
+#ifndef  USE_PANNABLE_AREA
   gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scrolled_window), 
 					vbox);
-
   return scrolled_window;
+#else
+  hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA(pannable_area),
+					 vbox);
+  return pannable_area;
+#endif
 }
 
 static GtkWidget *cache_logs(appdata_t *appdata, log_t *log, int is_html) {
-
+#ifndef  USE_PANNABLE_AREA
   /* put this inside a scrolled view */
   GtkWidget *scrolled_window = gtk_scrolled_window_new(NULL, NULL);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window), 
   				 GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+#else
+  GtkWidget *pannable_area = hildon_pannable_area_new();
+#endif
 
   GtkWidget *table = gtk_table_new(4*gpx_number_of_logs(log), 3, FALSE);
   int cnt = 0;
@@ -483,12 +487,15 @@ static GtkWidget *cache_logs(appdata_t *appdata, log_t *log, int is_html) {
     cnt+=4;
   }
 
+#ifndef  USE_PANNABLE_AREA
   gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scrolled_window), 
 					table);
-
-  //  gtk_widget_show_all(scrolled_window);
-
   return scrolled_window;
+#else
+  hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA(pannable_area),
+					 table);
+  return pannable_area;
+#endif
 }
 
 #ifdef USE_MAEMO
@@ -518,6 +525,14 @@ static void on_notebook_page_change(GtkNotebook     *notebook,
     gtk_timeout_remove(context->handler_id);
 #endif
 
+  /* this is a workaround, around some bug in the gtktextwidget or so ... */
+  /* i tried to get info on this and everybody agreed that this is a bug */
+  /* in gtk but noone had a read fix. so i came up with this. */
+  /* seems to work ... */
+  if(strcasecmp(name, _("Logs")) == 0) {
+    gtk_widget_queue_resize(w);
+  }
+
   if(strcasecmp(name, _("Goto")) == 0) {
 #ifdef USE_MAEMO  
     context->handler_id = gtk_timeout_add(1000, screensaver_update, 
@@ -566,6 +581,12 @@ GtkWidget *cache_view(appdata_t *appdata, cache_t *cache) {
 #endif
 
   notebook =  gtk_notebook_new();
+#ifdef USE_MAEMO
+#if MAEMO_VERSION_MAJOR >= 5
+  /* prevents user from accidentially touching the breadcrumb trail */
+  gtk_notebook_set_tab_pos(GTK_NOTEBOOK(notebook), GTK_POS_BOTTOM);
+#endif
+#endif
 
   gtk_notebook_append_page(GTK_NOTEBOOK(notebook), 
        cache_overview(cache_context), gtk_label_new(_("Main")));
