@@ -24,7 +24,7 @@ extern void dbus_register(appdata_t *appdata);
 extern int dbus_mm_set_position(appdata_t *appdata, pos_t *pos);
 
 #ifdef ENABLE_BROWSER_INTERFACE
-extern int dbus_browser_url(appdata_t *appdata, char *url);
+extern int browser_url(appdata_t *appdata, char *url);
 #endif
 
 #endif // HDR_DBUS_H
