@@ -289,6 +289,10 @@ void gconf_load_state(appdata_t *appdata) {
   /* ----- set all kinds of defaults ------- */
 
   if(!appdata->home.lon || !appdata->home.lat) {
+    /* if we get here, there's no config at all yet. So this is a */
+    /* good place to set all kinds of useful defaults */
+    appdata->load_images = TRUE;
+
     appdata->home.lat = DEFAULT_LAT;
     appdata->home.lon = DEFAULT_LON;
   }
@@ -316,7 +320,7 @@ void gconf_load_state(appdata_t *appdata) {
     char *p = getenv("HOME");
     if(p) {
       /* build image path in home directory */
-      appdata->image_path = 
+      appdata->image_path =
 	malloc(strlen(p)+strlen(DEFAULT_IMAGE_PATH_HOME)+2);
       strcpy(appdata->image_path, p);
       if(appdata->image_path[strlen(appdata->image_path)-1] != '/')
@@ -325,6 +329,15 @@ void gconf_load_state(appdata_t *appdata) {
     } else
 #endif
     appdata->image_path = strdup(DEFAULT_IMAGE_PATH);
+
+  } else {
+    /* some versions old versions messed up the path */
+    if(appdata->image_path[strlen(appdata->image_path)-1] != '/') {
+      printf("adjusting image path\n");
+      appdata->image_path = realloc(appdata->image_path, 
+				    strlen(appdata->image_path)+2);
+      strcat(appdata->image_path, "/");
+    }
   }
 
   if(!appdata->mmpoi_path) {
