@@ -41,6 +41,10 @@
 #ifdef HILDON_HELP
 #include <hildon/hildon-help.h>
 #endif
+#if MAEMO_VERSION_MAJOR >= 5
+#define USE_PANNABLE_AREA
+#include <hildon/hildon-pannable-area.h>
+#endif
 #endif
 
 #include <gtk/gtk.h>
@@ -111,8 +115,10 @@ typedef struct {
   /* keep track of all html views so zoom events can be delivered */
   struct html_view *html_view;
 
+#ifndef REQUIRES_CLOSE_BUTTON
   /* this is being activated and de-activated on selection/deselection */
   GtkWidget *menu_remove, *menu_close;
+#endif
 
   /* do enable/disable the edit entries */
   GtkWidget *menu_cut, *menu_copy, *menu_paste;
