@@ -17,18 +17,11 @@
  * along with GPXView.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* todo:
-   - make sure identical files aren't written in parallel
-   - cope with threads still running while view is destroyed
-   - free thread chain
- */
-
 #include "gpxview.h"
 
 typedef struct load_context {
   int active;
   GMutex *mutex;
-  //  GThread *thread;
   GtkWidget *view;
   char *url, *path;
   GtkHTMLStream *stream;
@@ -96,9 +89,6 @@ gpointer loader_thread(gpointer data) {
 
   printf("%p: loader thread for %s running\n", self, context->url);
 
-  //  sleep(5);  // for testing
-  //  printf("%p: running after sleep ...\n", self);
-  
   result = gnome_vfs_open(&handle, context->url, GNOME_VFS_OPEN_READ);
   if(result != GNOME_VFS_OK) {
     g_print("%p: open error: %s\n", self, gnome_vfs_result_to_string(result));
@@ -109,7 +99,6 @@ gpointer loader_thread(gpointer data) {
   
   /* try to open file for writing */
   FILE *f = fopen(context->path, "wb");
-  //  printf("%p: opened %s\n", self, context->path);
   int running = TRUE;
   
   do {
@@ -156,8 +145,6 @@ static void on_request_url(GtkHTML *html, const gchar *url,
   
   http_context_t *context = (http_context_t*)data;
 
-  //  printf("request for url %s\n", url);
-
   if(context->cache) {
     /* try to build local path */
     char *path = malloc(strlen(context->appdata->image_path)+
@@ -366,6 +353,17 @@ void html_copy_to_clipboard(appdata_t *appdata) {
   gtk_html_copy(GTK_HTML(appdata->active_buffer));
 }
 
+#ifdef USE_PANNABLE_AREA
+/* eat the button events */
+static gboolean on_button_press(GtkWidget *widget, GdkEventButton *event,
+				gpointer user_data) {
+  return TRUE;
+}
+#endif
+
+/* panning a gtkhtml view currently doesn't work well */
+#undef PANNABLE_HTML
+
 /* the cache descriptions are not valid html and need some surrounding stuff */
 static const char *html_start = "<html><head>"
   "<meta http-equiv=content-type content=\"text/html; charset=UTF-8\">"
@@ -405,7 +403,7 @@ GtkWidget *html_view(appdata_t *appdata, char *text,
 #endif
 
     if(anchor) {
-      while (gtk_events_pending ())
+      while(gtk_events_pending())
 	gtk_main_iteration ();
 
       gtk_html_jump_to_anchor(GTK_HTML(context->view), anchor);
@@ -417,6 +415,15 @@ GtkWidget *html_view(appdata_t *appdata, char *text,
     *h = g_new0(struct html_view, 1);
     (*h)->view = view;
 
+#ifdef PANNABLE_HTML
+    /* this causes finger scrolling to work nicely but also prevents */
+    /* copy'n paste from working correctly */
+    gtk_widget_set_sensitive(GTK_WIDGET(view), FALSE);
+
+    g_signal_connect(G_OBJECT(view), "button-press-event", 
+		     G_CALLBACK(on_button_press), NULL);
+#endif
+
     g_signal_connect(G_OBJECT(view), "destroy", 
 		     G_CALLBACK(on_destroy_htmlview), context);
   } else {
@@ -427,6 +434,22 @@ GtkWidget *html_view(appdata_t *appdata, char *text,
     gtk_text_view_set_editable(GTK_TEXT_VIEW(view), FALSE);
     gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(view), FALSE);
 
+#ifdef USE_PANNABLE_AREA
+    /* only the caches description has "scrollwin" enabled since selection */
+    /* is only needed there */
+    if(!scrollwin) {
+      GdkColor color;
+      gdk_color_parse("lightgrey", &color);
+
+      gtk_widget_set_sensitive(GTK_WIDGET(view), FALSE);
+
+      /* settings the widget insensitive also sets its background */
+      /* to the "insesitive" state which makes it pretty inreadable */
+      /* on fremantle. Thus set it to light grey */
+      gtk_widget_modify_base(view, GTK_STATE_INSENSITIVE, &color);
+    }
+#endif
+
     g_signal_connect(G_OBJECT(view), "destroy", 
 		     G_CALLBACK(on_destroy_textview), appdata);
   } 
@@ -435,11 +458,28 @@ GtkWidget *html_view(appdata_t *appdata, char *text,
 		   G_CALLBACK(focus_in), appdata);
 
   if(scrollwin) {
+#ifndef USE_PANNABLE_AREA
     GtkWidget *scrolled_window = gtk_scrolled_window_new(NULL, NULL);
-    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window), 
-			    GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-    gtk_container_add (GTK_CONTAINER (scrolled_window), view);
+    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW (scrolled_window), 
+		     GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+    gtk_container_add(GTK_CONTAINER(scrolled_window), view);
     return scrolled_window;
+#else
+#ifndef PANNABLE_HTML
+  if(is_html) { 
+      GtkWidget *scrolled_window = gtk_scrolled_window_new(NULL, NULL);
+      gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW (scrolled_window), 
+		     GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+      gtk_container_add(GTK_CONTAINER(scrolled_window), view);
+      return scrolled_window;
+    } else
+#endif
+    {
+      GtkWidget *pannable_area = hildon_pannable_area_new();
+      gtk_container_add(GTK_CONTAINER(pannable_area), view);
+      return pannable_area;    
+    }
+#endif
   }
 
   return view;
