@@ -81,7 +81,7 @@ const char *tb_icon_name[] = {
 /* ICON_MISC         */
 const char *misc_icon_name[] = {
   "maemo-mapper-out", "override", "locked", "unlocked", "found", 
-  "maemo-mapper-in", "note", "earth"
+  "maemo-mapper-in", "note", "delete"
 };
 
 /* ICON_FILE         */
