@@ -27,7 +27,9 @@
 #include "custom_rating_renderer.h"
 #include "custom_type_renderer.h"
 
+#ifdef USE_MAEMO
 #include <hildon/hildon-banner.h>
+#endif
 
 #include <locale.h>
 
@@ -327,12 +329,11 @@ static void cachelist_update_reset1(GtkAdjustment *adj,
 				    gpointer user_data) {
   cachelist_timer_reset((appdata_t*)user_data);
 }
-  
+
 static GtkWidget *cachelist_create(appdata_t *appdata, gpx_t *gpx,
 				   cache_t *sel_cache) {
   GtkCellRenderer *renderer;
   GtkWidget       *view;
-  GtkWidget       *scrolled_window;
   GtkListStore    *store;
   GtkTreeIter     iter;
 
@@ -494,16 +495,23 @@ static GtkWidget *cachelist_create(appdata_t *appdata, gpx_t *gpx,
   ce->appdata = appdata;
   ce->path = path;
   ce->done = FALSE;
+
   g_signal_connect(view, "expose-event", 
 		   (GCallback)cachelist_expose, ce);
   g_signal_connect(view, "destroy",
 		   (GCallback)cachelist_destroy, ce);
 
   /* put this inside a scrolled view */
-  scrolled_window = gtk_scrolled_window_new (NULL, NULL);
+#ifndef USE_PANNABLE_AREA
+  GtkWidget *scrolled_window = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window), 
 				 GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
   gtk_container_add(GTK_CONTAINER(scrolled_window), view);
+#else
+  GtkWidget *pannable_area = hildon_pannable_area_new();
+  
+  gtk_container_add(GTK_CONTAINER(pannable_area), view);
+#endif
 
   /* add a timer for automatic update */
   g_assert(!appdata->cachelist_handler_id);
@@ -514,12 +522,22 @@ static GtkWidget *cachelist_create(appdata_t *appdata, gpx_t *gpx,
   g_signal_connect(view, "button-press-event", 
 		   (GCallback)cachelist_update_reset0, appdata);
 
+#ifndef USE_PANNABLE_AREA
   g_signal_connect(gtk_scrolled_window_get_vadjustment(
 		       GTK_SCROLLED_WINDOW(scrolled_window)), 
 			   "value-changed", 
 			   (GCallback)cachelist_update_reset1, appdata);
 
   return scrolled_window;
+#else
+  g_signal_connect(hildon_pannable_area_get_vadjustment(
+		       HILDON_PANNABLE_AREA(pannable_area)), 
+			   "value-changed", 
+			   (GCallback)cachelist_update_reset1, appdata);
+
+
+  return pannable_area;
+#endif
 }
 
 #ifndef USE_MAEMO
@@ -555,6 +573,9 @@ enum {
   GPXLIST_COL_DATE,
   GPXLIST_COL_CACHES,
   GPXLIST_COL_OPEN,
+#ifdef USE_PANNABLE_AREA
+  GPXLIST_COL_DELETE,
+#endif
   GPXLIST_COL_DATA,
   GPXLIST_NUM_COLS
 } ;
@@ -593,10 +614,53 @@ static void gpxlist_set(GtkListStore *store, GtkTreeIter *iter, gpx_t *gpx) {
 		     GPXLIST_COL_DATE, gpx->closed?NULL:date_str,
 		     GPXLIST_COL_OPEN, !gpx->closed,
 		     GPXLIST_COL_CACHES, gpx->closed?NULL:cnum,
+#ifdef USE_PANNABLE_AREA
+		     GPXLIST_COL_DELETE, icon_get(ICON_MISC, 7),
+#endif
 		     GPXLIST_COL_DATA, gpx,
 		     -1);
 }
 
+static void gpxlist_remove(appdata_t *appdata, 
+			   GtkListStore *store, GtkTreeIter *iter, 
+			   gpx_t *gpx) {
+
+  printf("removing %s\n", gpx->name);
+  
+  /* de-chain */
+  gpx_t **prev = &appdata->gpx;
+  while(*prev != gpx) prev = &((*prev)->next);
+  *prev = gpx->next;
+  
+  /* remove gconf entry if file was closed */
+  gconf_remove_closed_name(appdata, gpx->filename);
+  
+  /* free gpx itself */
+  gpx_free(gpx);
+  
+  /* and remove from store */
+  gtk_list_store_remove(store, iter);
+}
+
+static void gpxlist_close(appdata_t *appdata,
+			  GtkListStore *store, GtkTreeIter *iter, 
+			  gpx_t *gpx) {
+  
+  printf("closing %s\n", gpx->name);
+
+  g_assert(!gpx->closed);
+  gpx->closed = TRUE;
+  
+  /* free all associated caches */
+  gpx_free_caches(gpx);
+  
+  /* update entry */
+  gpxlist_set(store, iter, gpx);
+  
+  /* save name in gconf so we know this has been closed */
+  gconf_save_closed_name(appdata, gpx->filename, gpx->name);
+}
+
 static void gpxlist_view_onRowActivated(GtkTreeView *treeview,
 			  GtkTreePath        *path,
 			  GtkTreeViewColumn  *col,
@@ -609,62 +673,114 @@ static void gpxlist_view_onRowActivated(GtkTreeView *treeview,
     gpx_t *gpx;
     gtk_tree_model_get(model, &iter, GPXLIST_COL_DATA, &gpx, -1);
 
-    /* this gpx file may be closed. Since the user definitely wants */
-    /* to use it, we just open it again */
-    if(gpx->closed) {
-      gpx_dialog_t *dialog = gpx_busy_dialog_new(GTK_WIDGET(appdata->window));
-      gpx_t *new = NULL;
-    
-      if(g_file_test(gpx->filename, G_FILE_TEST_IS_DIR)) 
-	new = gpx_parse_dir(dialog, gpx->filename);
-      else
-	new = gpx_parse(dialog, gpx->filename);
+#ifdef USE_PANNABLE_AREA
+    /* get name of column the user clicked on */
+    const char *col_name = NULL;
+    if(col) col_name = gtk_tree_view_column_get_title(col);
 
-      if(new) {
-	gpx_t **prev = &(appdata->gpx);
-	while(*prev && *prev != gpx)
-	  prev = &(*prev)->next;
+    if(col_name && !strcmp(col_name, "Del")) {
+      printf("clicked delete\n");
 
-	/* this entry _must_ be in the list */
-	g_assert(*prev);
+      /* ask user what he wants */
+      GtkWidget *dialog = gtk_message_dialog_new(
+  	         GTK_WINDOW(appdata->window),
+		 GTK_DIALOG_DESTROY_WITH_PARENT,
+		 GTK_MESSAGE_QUESTION, GTK_BUTTONS_CANCEL,
+		 _("Do you want to close this entry only or do "
+		   "you want to remove it completely from the list?"));
 
-	/* replace gpx entry with the new "open" one */
-	(*prev) = new;
-	new->next = gpx->next;
-	gpx->next = NULL;
-	
-	/* free old closed one */
-	gpx_free(gpx);
+      gtk_dialog_add_buttons(GTK_DIALOG(dialog), 
+			     _("Remove"), 1,
+			     _("Close"), 2,
+			     NULL);
 
-	gpx = new;
+      if(gpx->closed)
+	gtk_dialog_set_response_sensitive(GTK_DIALOG(dialog), 2, FALSE);
 
-	/* finally update the visible list */
-	gpxlist_set(appdata->gpxstore, &iter, gpx);
+      gtk_window_set_title(GTK_WINDOW(dialog), _("Remove entry?"));
+      
+      /* set the active flag again if the user answered "no" */
+      switch(gtk_dialog_run(GTK_DIALOG(dialog))) {
 
-	/* and remove gconf entry */
-	gconf_remove_closed_name(appdata, gpx->filename);
+      case 1:
+	gpxlist_remove(appdata, GTK_LIST_STORE(model), &iter, gpx);
+	break;
 
-	gtk_widget_set_sensitive(appdata->menu_close, TRUE);
-      } else {
-	printf("unable to reopen file %s\n", gpx->filename);
-	return;
+      case 2:
+	gpxlist_close(appdata, GTK_LIST_STORE(model), &iter, gpx);
+	break;
+
+      default:
+	break;
       }
       
-      gpx_busy_dialog_destroy(dialog);
-    }
-#ifndef USE_MAEMO
-    cachelist_dialog(appdata, gpx);
-#else
-    gtk_container_remove(GTK_CONTAINER(appdata->vbox), appdata->cur_view);
-    appdata->cur_view = cachelist_create(appdata, gpx, NULL);
-    gtk_box_pack_start_defaults(GTK_BOX(appdata->vbox), appdata->cur_view);
-    gtk_widget_show_all(appdata->vbox);
+      gtk_widget_destroy(dialog);
 
-    crumb_add(appdata, gpx->name, CRUMB_CACHELIST, gpx);
+    } else
 #endif
+    {
+
+      /* this gpx file may be closed. Since the user definitely wants */
+      /* to use it, we just open it again */
+      if(gpx->closed) {
+	gpx_dialog_t *dialog = 
+	  gpx_busy_dialog_new(GTK_WIDGET(appdata->window));
+	gpx_t *new = NULL;
+	
+	if(g_file_test(gpx->filename, G_FILE_TEST_IS_DIR)) 
+	  new = gpx_parse_dir(dialog, gpx->filename);
+	else
+	  new = gpx_parse(dialog, gpx->filename);
+	
+	if(new) {
+	  gpx_t **prev = &(appdata->gpx);
+	  while(*prev && *prev != gpx)
+	    prev = &(*prev)->next;
+	  
+	  /* this entry _must_ be in the list */
+	  g_assert(*prev);
+	  
+	  /* replace gpx entry with the new "open" one */
+	  (*prev) = new;
+	  new->next = gpx->next;
+	  gpx->next = NULL;
+	  
+	  /* free old closed one */
+	  gpx_free(gpx);
+	  
+	  gpx = new;
+	  
+	  /* finally update the visible list */
+	  gpxlist_set(appdata->gpxstore, &iter, gpx);
+	  
+	  /* and remove gconf entry */
+	  gconf_remove_closed_name(appdata, gpx->filename);
+	  
+#ifndef USE_PANNABLE_AREA
+	  gtk_widget_set_sensitive(appdata->menu_close, TRUE);
+#endif
+	} else {
+	  printf("unable to reopen file %s\n", gpx->filename);
+	  return;
+	}
+      
+	gpx_busy_dialog_destroy(dialog);
+      }
+#ifndef USE_MAEMO
+      cachelist_dialog(appdata, gpx);
+#else
+      gtk_container_remove(GTK_CONTAINER(appdata->vbox), appdata->cur_view);
+      appdata->cur_view = cachelist_create(appdata, gpx, NULL);
+      gtk_box_pack_start_defaults(GTK_BOX(appdata->vbox), appdata->cur_view);
+      gtk_widget_show_all(appdata->vbox);
+      
+      crumb_add(appdata, gpx->name, CRUMB_CACHELIST, gpx);
+#endif
+    }
   }
 }
 
+#ifndef USE_PANNABLE_AREA
 static gboolean
 view_selection_func(GtkTreeSelection *selection, GtkTreeModel *model,
 		     GtkTreePath *path, gboolean path_currently_selected,
@@ -684,25 +800,30 @@ view_selection_func(GtkTreeSelection *selection, GtkTreeModel *model,
   
   return TRUE; /* allow selection state to change */
 }
+#endif
 
 static GtkWidget *gpxlist_create_view_and_model(appdata_t *appdata, 
 						gpx_t *sel_gpx) {
   gpx_t               *gpx = appdata->gpx;
   GtkCellRenderer     *renderer;
-  GtkWidget           *scrolled_window;
 
   /* saved displayed items */
   appdata->cur_items = appdata->gpxlist_items;
 
+#ifndef USE_PANNABLE_AREA
   /* nothing selected yet */
   gtk_widget_set_sensitive(appdata->menu_remove,  FALSE);
   gtk_widget_set_sensitive(appdata->menu_close,   FALSE);
+#endif
 
   appdata->gpxview = gtk_tree_view_new ();
+
   GtkTreeSelection *selection = 
     gtk_tree_view_get_selection(GTK_TREE_VIEW(appdata->gpxview));
+#ifndef USE_PANNABLE_AREA
   gtk_tree_selection_set_select_function(selection, view_selection_func, 
 					 appdata, NULL);
+#endif
 
   /* --- "Icon" column --- */
   renderer = gtk_cell_renderer_pixbuf_new();
@@ -759,10 +880,24 @@ static GtkWidget *gpxlist_create_view_and_model(appdata_t *appdata,
 		NULL);
   }
 
+#ifdef USE_PANNABLE_AREA
+  /* --- "Delete" column --- */
+  renderer = gtk_cell_renderer_pixbuf_new();
+  gtk_tree_view_insert_column_with_attributes(GTK_TREE_VIEW(appdata->gpxview),
+		  -1, "Del", renderer, 
+		  "pixbuf", GPXLIST_COL_DELETE,
+		  "sensitive", GPXLIST_COL_OPEN, 
+	          NULL);
+#endif
+
   /* build and fill the store */
   appdata->gpxstore = gtk_list_store_new(GPXLIST_NUM_COLS, GDK_TYPE_PIXBUF,
 			 G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, 
-			 G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_POINTER);
+			 G_TYPE_STRING, G_TYPE_BOOLEAN, 
+#ifdef USE_PANNABLE_AREA
+			 GDK_TYPE_PIXBUF, 
+#endif
+			 G_TYPE_POINTER);
 
   GtkTreePath *path = NULL; 
   GtkTreeIter sel_iter;
@@ -798,13 +933,20 @@ static GtkWidget *gpxlist_create_view_and_model(appdata_t *appdata,
   g_signal_connect(appdata->gpxview, "row-activated", 
 		   (GCallback)gpxlist_view_onRowActivated, appdata);
 
-  /* put it into a scrolled window */
-  scrolled_window = gtk_scrolled_window_new (NULL, NULL);
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(scrolled_window), 
-				  GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+  /* put this inside a scrolled view */
+#ifndef USE_PANNABLE_AREA
+  GtkWidget *scrolled_window = gtk_scrolled_window_new(NULL, NULL);
+  gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window), 
+				 GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
   gtk_container_add(GTK_CONTAINER(scrolled_window), appdata->gpxview);
 
   return scrolled_window;
+#else
+  GtkWidget *pannable_area = hildon_pannable_area_new();
+  gtk_container_add(GTK_CONTAINER(pannable_area), appdata->gpxview);
+
+  return pannable_area;
+#endif
 }
 
 /* add last entry in gpx list to visual representation */
@@ -886,72 +1028,60 @@ cb_menu_precpos(GtkWidget *window, gpointer data) {
   precise_position((appdata_t *)data);
 }
 
+#ifndef USE_PANNABLE_AREA
 static void 
 cb_menu_close(GtkWidget *window, gpointer data) {
   appdata_t *appdata = (appdata_t *)data;
   GtkTreeSelection *selection;
-  printf("selected close\n");
-
-  /* the entry cannot be closed again */
-  gtk_widget_set_sensitive(appdata->menu_close,   FALSE);
-
-  selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(appdata->gpxview));
   GtkTreeModel     *model;
   GtkTreeIter       iter;
+  
+  printf("selected close\n");
+  
+  /* the entry cannot be closed again */
+  gtk_widget_set_sensitive(appdata->menu_close,   FALSE);
+  
+  selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(appdata->gpxview));
+
+  printf("gpxlist close\n");
 
   if (gtk_tree_selection_get_selected(selection, &model, &iter)) {
-    gpx_t *gpx;
+    gpx_t *gpx = NULL;
     gtk_tree_model_get(model, &iter, GPXLIST_COL_DATA, &gpx, -1);
 
-    g_assert(!gpx->closed);
-    gpx->closed = TRUE;
-
-    /* free all associated caches */
-    gpx_free_caches(gpx);
-
-    /* update entry */
-    gpxlist_set(appdata->gpxstore, &iter, gpx);
-
-    /* save name in gconf so we know this has been closed */
-    gconf_save_closed_name(appdata, gpx->filename, gpx->name);
+    if(gpx) gpxlist_close(appdata, GTK_LIST_STORE(model), &iter, gpx);
+  } else {
+    g_print ("no row selected.\n");
   }
 }
 
 static void 
 cb_menu_remove(GtkWidget *window, gpointer data) {
   appdata_t *appdata = (appdata_t *)data;
-  GtkTreeSelection *selection;
-  GtkTreeModel     *model;
-  GtkTreeIter       iter;
 
   /* disable menu item */
   gtk_widget_set_sensitive(appdata->menu_remove,  FALSE);
   gtk_widget_set_sensitive(appdata->menu_close,   FALSE);
 
-  selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(appdata->gpxview));
-  if (gtk_tree_selection_get_selected(selection, &model, &iter)) {
-    gpx_t *gpx;
+  GtkTreeModel     *model;
+  GtkTreeIter       iter;
+  GtkTreeSelection *selection =
+    gtk_tree_view_get_selection(GTK_TREE_VIEW(appdata->gpxview));
+
+  printf("gpxlist remove\n");
+
+  if(gtk_tree_selection_get_selected(selection, &model, &iter)) {
+    gpx_t *gpx = NULL;
     gtk_tree_model_get(model, &iter, GPXLIST_COL_DATA, &gpx, -1);
-
-    /* de-chain */
-    gpx_t **prev = &appdata->gpx;
-    while(*prev != gpx) prev = &((*prev)->next);
-    *prev = gpx->next;
-
-    /* remove gconf entry if file was closed */
-    gconf_remove_closed_name(appdata, gpx->filename);
-
-    /* free gpx itself */
-    gpx_free(gpx);
-
-    /* and remove from store */
-    gtk_list_store_remove(GTK_LIST_STORE(model), &iter);
-
+    
+    if(gpx) gpxlist_remove(appdata, GTK_LIST_STORE(model), &iter, gpx);
   } else {
     g_print ("no row selected.\n");
   }
 }
 
+#endif // !USE_PANNABLE_AREA
+
 static void search_result_free(gpx_t *result) {
   printf("freeing search results\n");    
 
@@ -1363,6 +1493,7 @@ void menu_create(appdata_t *appdata) {
   gtk_menu_append(GTK_MENU_SHELL(submenu), item);
   g_signal_connect(item, "activate", GTK_SIGNAL_FUNC(cb_menu_adddir), appdata);
 
+#ifndef USE_PANNABLE_AREA
   gtk_menu_append(GTK_MENU_SHELL(submenu), gtk_separator_menu_item_new());
 
   appdata->menu_close = 
@@ -1374,6 +1505,7 @@ void menu_create(appdata_t *appdata) {
     item = gtk_menu_item_new_with_label( _("Remove") );
   gtk_menu_append(GTK_MENU_SHELL(submenu), item);
   g_signal_connect(item, "activate", GTK_SIGNAL_FUNC(cb_menu_remove), appdata);
+#endif
 
 #ifdef USE_MAEMO
   appdata->menu_export = 
@@ -1759,8 +1891,10 @@ static void crumb_add(appdata_t *appdata, char *name, int level,
   if(level != CRUMB_GPXLIST) {
     /* disable gpxlist related menu entries */
     gtk_widget_set_sensitive(appdata->menu_import,  FALSE);
+#ifndef USE_PANNABLE_AREA
     gtk_widget_set_sensitive(appdata->menu_remove,  FALSE);
     gtk_widget_set_sensitive(appdata->menu_close,   FALSE);
+#endif
   }
 
   hildon_bread_crumb_trail_push_text(HILDON_BREAD_CRUMB_TRAIL(appdata->bct),
